==> moodle-2.2.10.txz: usr/local/www/moodle/message/output/jabber/lang/en/message_jabber.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'message_jabber', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   message_jabber
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configjabberhost'] = 'The server to connect to to send jabber message notifications';
$string['configjabberserver'] = 'XMPP host ID (can be left empty if the same as Jabber host)';
$string['configjabberusername'] = 'The user name to use when connecting to the Jabber server';
$string['configjabberpassword'] = 'The password to use when connecting to the Jabber server';
$string['configjabberport'] = 'The port to use when connecting to the Jabber server';
$string['jabberhost'] = 'Jabber host';
$string['jabberid'] = 'Jabber ID';
$string['jabberserver'] = 'Jabber server';
$string['jabberusername'] = 'Jabber user name';
$string['jabberpassword'] = 'Jabber password';
$string['jabberport'] = 'Jabber port';
$string['notconfigured'] = 'The Jabber server hasn\'t been configured so Jabber messages cannot be sent';
$string['pluginname'] = 'Jabber message';

==> moodle30-3.0.5.txz: usr/local/www/moodle/message/output/jabber/lang/en/message_jabber.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'message_jabber', language 'en'
 *
 * @package    message_jabber
 * @copyright  1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['configjabberhost'] = 'The server to connect to to send jabber message notifications';
$string['configjabberserver'] = 'XMPP host ID (can be left empty if the same as Jabber host)';
$string['configjabberusername'] = 'The user name to use when connecting to the Jabber server';
$string['configjabberpassword'] = 'The password to use when connecting to the Jabber server';
$string['configjabberport'] = 'The port to use when connecting to the Jabber server';
$string['jabberhost'] = 'Jabber host';
$string['jabberid'] = 'Jabber ID';
$string['jabberserver'] = 'Jabber server';
$string['jabberusername'] = 'Jabber user name';
$string['jabberpassword'] = 'Jabber password';
$string['jabberport'] = 'Jabber port';
$string['notconfigured'] = 'The Jabber server hasn\'t been configured so Jabber messages cannot be sent';
$string['pluginname'] = 'Jabber message';
